package ru.myitschool.work.api

import android.content.Context
import androidx.core.content.ContentProviderCompat.requireContext
import okhttp3.OkHttpClient
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import ru.myitschool.work.api.login.ApiServiceLogin
import ru.myitschool.work.api.main.ApiServiceMain
import ru.myitschool.work.api.scan.ApiServiceScan
import ru.myitschool.work.core.Constants.SERVER_ADDRESS
import ru.myitschool.work.utils.AuthPreferences
import java.util.concurrent.TimeUnit


class RetrofitClient(private val context: Context) {

    private val serverAddress = SERVER_ADDRESS
    private var authPreferences: AuthPreferences = AuthPreferences(context)

    private val httpClient = OkHttpClient.Builder()
        .connectTimeout(30, TimeUnit.SECONDS)
        .addInterceptor(BasicAuthInterceptor(
            authPreferences.getLogin() ?: "",
            authPreferences.getPassword() ?: ""
        ))
        .readTimeout(30, TimeUnit.SECONDS)
        .build()

    private val retrofit: Retrofit by lazy {
        Retrofit.Builder()
            .baseUrl(serverAddress)
            .client(httpClient)
            .addConverterFactory(GsonConverterFactory.create())
            .build()
    }

    fun getApiServiceLogin(): ApiServiceLogin {
        return retrofit.create(ApiServiceLogin::class.java)
    }

    fun getApiServiceMain(): ApiServiceMain {
        return retrofit.create(ApiServiceMain::class.java)
    }

    fun getApiServiceScan(): ApiServiceScan {
        return retrofit.create(ApiServiceScan::class.java)
    }
}